@@ -85,7 +85,7 @@ class Configuration(object):
     PKGDIR = 'wx'
     # The name of the top-level package
 
-    SIP_ABI = '12.8'
+    SIP_ABI = '12.9'
     SIP_TRACE = False
 
     # ---------------------------------------------------------------
@@ -724,6 +724,22 @@ def getEtgSipCppFiles(etg):
 def getEtgSipHeaders(etg):
     return _getSbfValue(etg, 'headers')
 
+def generateVersionFiles(cfg):
+    # create the package's __version__ module
+    with open(opj(cfg.PKGDIR, '__version__.py'), 'w') as fid:
+        fid.write("# This file was generated by wxPython's wscript.\n\n"
+                  "VERSION_STRING    = '%(VERSION)s'\n"
+                  "MAJOR_VERSION     = %(VER_MAJOR)s\n"
+                  "MINOR_VERSION     = %(VER_MINOR)s\n"
+                  "RELEASE_NUMBER    = %(VER_RELEASE)s\n"
+                  "BUILD_TYPE        = '%(BUILD_TYPE)s'\n\n"
+                  "VERSION = (MAJOR_VERSION, MINOR_VERSION, RELEASE_NUMBER, '%(VER_FLAGS)s')\n"
+                  % cfg.__dict__)
+    # and one for the demo folder too
+    with open('demo/version.py', 'w') as fid:
+        fid.write("# This file was generated by wxPython's wscript.\n\n"
+                  "VERSION_STRING = '%(VERSION)s'\n"
+                  % cfg.__dict__)
 
 def findCmd(cmd):
     """
@@ -1065,7 +1081,7 @@ def updateLicenseFiles(cfg):
     # Combine the relevant files into a single LICENSE.txt file
     text = ''
     for filename in ['preamble.txt', 'licence.txt', 'lgpl.txt', 'sip-license.txt']:
-        with open(opj('license', filename), 'r') as f:
+        with open(opj('license', filename), 'r', encoding='utf-8') as f:
             text += f.read() + '\n\n'
     with open('LICENSE.txt', 'w') as f:
         f.write(text)
