@@ -3,7 +3,7 @@
 # Author:      Robin Dunn
 #
 # Created:     2-Sept-2011
-# Copyright:   (c) 2011-2018 by Total Control Software
+# Copyright:   (c) 2011-2020 by Total Control Software
 # License:     wxWindows License
 #---------------------------------------------------------------------------
 
@@ -35,6 +35,9 @@ def run():
     c.addPrivateCopyCtor()
     c.mustHaveApp()
 
+    # remove the const overload of GetSelectedBitmap
+    c.find('GetSelectedBitmap').findOverload('', isConst=True).ignore()
+
 
     #-----------------------------------------------------------------
     tools.doCommonTweaks(module)
