@@ -22,10 +22,7 @@ public:
     DEFINE_STD_WXCOLOUR_CONSTRUCTORS
 
     // copy ctors and assignment operators
-    wxColour(const wxColour& col)
-    {
-        *this = col;
-    }
+    wxDECLARE_DEFAULT_COPY_CTOR(wxColour)
 
     wxColour& operator=(const wxColour& col);
 
