@@ -19,6 +19,8 @@
     #import <Cocoa/Cocoa.h>
 #endif
 
+#include <vector>
+
 //
 // shared between Cocoa and Carbon
 //
@@ -34,10 +36,17 @@ OSStatus WXDLLIMPEXP_CORE wxMacDrawCGImage(
                                CGContextRef    inContext,
                                const CGRect *  inBounds,
                                CGImageRef      inImage) ;
+
 void WXDLLIMPEXP_CORE wxOSXDrawNSImage(
                                            CGContextRef    inContext,
                                            const CGRect *  inBounds,
                                            WX_NSImage      inImage) ;
+
+void WXDLLIMPEXP_CORE wxOSXDrawNSImage(
+                                           CGContextRef    inContext,
+                                           const CGRect *  inBounds,
+                                           WX_NSImage      inImage,
+                                           wxCompositionMode composition) ;
 WX_NSImage WXDLLIMPEXP_CORE wxOSXGetSystemImage(const wxString& name);
 WX_NSImage WXDLLIMPEXP_CORE wxOSXGetNSImageFromCGImage( CGImageRef image, double scale = 1.0, bool isTemplate = false);
 WX_NSImage WXDLLIMPEXP_CORE wxOSXGetNSImageFromIconRef( WXHICON iconref );
@@ -172,7 +181,10 @@ public :
     virtual void        DoNotifyFocusEvent(bool receivedFocus, wxWidgetImpl* otherWindow);
 
     virtual void        SetupKeyEvent(wxKeyEvent &wxevent, NSEvent * nsEvent, NSString* charString = NULL);
-    virtual void        SetupMouseEvent(wxMouseEvent &wxevent, NSEvent * nsEvent);
+
+    using MouseEvents = std::vector<wxMouseEvent>;
+    virtual MouseEvents TranslateMouseEvent(NSEvent * nsEvent);
+
     void                SetupCoordinates(wxCoord &x, wxCoord &y, NSEvent *nsEvent);
     virtual bool        SetupCursor(NSEvent* event);
 
@@ -220,9 +232,14 @@ public :
     // from the same pimpl class.
     virtual void                controlTextDidChange();
 
+    virtual void                AdjustClippingView(wxScrollBar* horizontal, wxScrollBar* vertical) wxOVERRIDE;
+    virtual void                UseClippingView(bool clip) wxOVERRIDE;
+    virtual WXWidget            GetContainer() const wxOVERRIDE { return m_osxClipView ? m_osxClipView : m_osxView; }
+
 protected:
     WXWidget m_osxView;
-    
+    WXWidget m_osxClipView;
+
     // begins processing of native key down event, storing the native event for later wx event generation
     void BeginNativeKeyDownEvent( NSEvent* event );
     // done with the current native key down event
@@ -449,6 +466,17 @@ public:
 
     @end
 
+    @interface wxNSSearchField : NSSearchField
+    {
+        wxNSTextFieldEditor* fieldEditor;
+        BOOL m_withinTextDidChange;
+    }
+
+    - (wxNSTextFieldEditor*) fieldEditor;
+    - (void) setFieldEditor:(wxNSTextFieldEditor*) fieldEditor;
+
+    @end
+
     @interface wxNSComboBox : NSComboBox
     {
         wxNSTextFieldEditor* fieldEditor;
