@@ -163,7 +163,7 @@
     or explicitly convert the return value:
         @code
             auto c = s[0].GetValue();
-            c = 'x';            // Doesn't modify the string neither.
+            c = 'x';            // Doesn't modify the string either.
             wxASSERT( s == "abc" );
         @endcode
 
@@ -319,7 +319,7 @@ public:
 
         Types used with wxString.
     */
-    //@{
+    ///@{
     typedef wxUniChar value_type;
     typedef wxUniChar char_type;
     typedef wxUniCharRef reference;
@@ -327,7 +327,7 @@ public:
     typedef const wxChar* const_pointer;
     typedef size_t size_type;
     typedef wxUniChar const_reference;
-    //@}
+    ///@}
 
 
     /**
@@ -340,7 +340,7 @@ public:
 
         See also the assign() STL-like function.
     */
-    //@{
+    ///@{
 
     /**
        Default constructor
@@ -451,7 +451,7 @@ public:
     */
     wxString operator =(wxUniChar c);
 
-    //@}
+    ///@}
 
 
 
@@ -463,7 +463,7 @@ public:
 
         See also the length(), size() or empty() STL-like functions.
     */
-    //@{
+    ///@{
 
 
     /**
@@ -498,7 +498,7 @@ public:
     */
     bool operator!() const;
 
-    //@}
+    ///@}
 
 
 
@@ -512,7 +512,7 @@ public:
         failure in @ref overview_debugging "debug builds", but no checks are
         done in release builds.
     */
-    //@{
+    ///@{
 
     /**
         Returns the character at position @a n (read-only).
@@ -590,7 +590,7 @@ public:
     */
     wxUniCharRef operator [](size_t i);
 
-    //@}
+    ///@}
 
 
     /**
@@ -600,7 +600,7 @@ public:
         strings. Although implicit conversion is quite convenient, you are advised
         to use wc_str() for the sake of clarity.
     */
-    //@{
+    ///@{
 
     /**
         Returns a lightweight intermediate class which is in turn implicitly
@@ -795,7 +795,7 @@ public:
     */
     const wxScopedCharBuffer ToUTF8() const;
 
-    //@}
+    ///@}
 
 
     /**
@@ -809,7 +809,7 @@ public:
 
         See also the insert() and append() STL-like functions.
     */
-    //@{
+    ///@{
 
     /**
        Appends the string literal @a psz.
@@ -885,7 +885,7 @@ public:
     */
     void operator +=(wxUniChar c);
 
-    //@}
+    ///@}
 
 
     /**
@@ -907,7 +907,7 @@ public:
 
         See also the compare() STL-like function.
     */
-    //@{
+    ///@{
 
     /**
         Case-sensitive comparison.
@@ -977,7 +977,7 @@ public:
     */
     bool EndsWith(const wxString& suffix, wxString *rest = NULL) const;
 
-    //@}
+    ///@}
 
 
     /**
@@ -989,6 +989,7 @@ public:
 
         See also the at() and the substr() STL-like functions.
     */
+    ///@{
 
     /**
         Returns a substring starting at @e first, with length @e count, or the rest of
@@ -1062,7 +1063,7 @@ public:
     */
     wxString BeforeLast(wxUniChar ch, wxString *rest = NULL) const;
 
-    //@}
+    ///@}
 
 
     /**
@@ -1072,7 +1073,7 @@ public:
         return a new string which contains the original text converted to the upper or
         lower case and leave the original string unchanged.
     */
-    //@{
+    ///@{
 
     /**
         Return the copy of the string with the first string character in the
@@ -1139,7 +1140,7 @@ public:
     */
     void UpperCase();
 
-    //@}
+    ///@}
 
 
     /**
@@ -1150,7 +1151,7 @@ public:
 
         See also the find(), rfind(), replace() STL-like functions.
     */
-    //@{
+    ///@{
 
     /**
         Searches for the given character @a ch.
@@ -1196,7 +1197,7 @@ public:
     size_t Replace(const wxString& strOld, const wxString& strNew,
                    bool replaceAll = true);
 
-    //@}
+    ///@}
 
 
 
@@ -1212,7 +1213,7 @@ public:
         string, it is returned in the output parameter even if the function
         returns @false because there is more text following it.
      */
-    //@{
+    ///@{
 
     /**
         Attempts to convert the string to a floating point number.
@@ -1376,7 +1377,7 @@ public:
     */
     bool ToULongLong(wxULongLong_t* val, int base = 10) const;
 
-    //@}
+    ///@}
 
 
     /**
@@ -1387,7 +1388,7 @@ public:
 
         See also the static Format() and FormatV() functions.
     */
-    //@{
+    ///@{
 
     /**
         Similar to the standard function @e sprintf(). Returns the number of
@@ -1419,7 +1420,7 @@ public:
     */
     int PrintfV(const wxString& pszFormat, va_list argPtr);
 
-    //@}
+    ///@}
 
 
     /**
@@ -1432,7 +1433,7 @@ public:
 
         See also the reserve() and resize() STL-like functions.
     */
-    //@{
+    ///@{
 
     /**
         Preallocate enough space for wxString to store @a nLen characters.
@@ -1504,7 +1505,7 @@ public:
     */
     void Clear();
 
-    //@}
+    ///@}
 
 
 
@@ -1513,7 +1514,7 @@ public:
 
         Miscellaneous other string functions.
     */
-    //@{
+    ///@{
 
     /**
         Returns @true if target appears anywhere in wxString; else @false.
@@ -1607,7 +1608,7 @@ public:
     */
     wxString& Truncate(size_t len);
 
-    //@}
+    ///@}
 
 
 
@@ -1620,7 +1621,7 @@ public:
         Please see any STL reference (e.g. http://www.cppreference.com/wiki/string/start)
         for their documentation.
     */
-    //@{
+    ///@{
 
     const_iterator begin() const;
     iterator begin();
@@ -1636,7 +1637,7 @@ public:
     reverse_iterator rend();
     const_reverse_iterator crend() const;
 
-    //@}
+    ///@}
 
 
 
@@ -1648,7 +1649,7 @@ public:
         Please see any STL reference (e.g. http://www.cppreference.com/wiki/string/start)
         for their documentation.
     */
-    //@{
+    ///@{
 
     wxString& append(const wxString& str, size_t pos, size_t n);
     wxString& append(const wxString& str);
@@ -1769,7 +1770,7 @@ public:
     bool ends_with(const char *sz) const;
     bool ends_with(const wchar_t *sz) const;
 
-    //@}
+    ///@}
 
 
 
@@ -1798,7 +1799,7 @@ public:
     */
     static wxString FormatV(const wxString& format, va_list argptr);
 
-    //@{
+    ///@{
     /**
         Converts given buffer of binary data from 8-bit string to wxString. In
         Unicode build, the string is interpreted as being in ISO-8859-1
@@ -1816,9 +1817,9 @@ public:
     */
     static wxString From8BitData(const char* buf, size_t len);
     static wxString From8BitData(const char* buf);
-    //@}
+    ///@}
 
-    //@{
+    ///@{
     /**
         Converts the string or character from an ASCII, 7-bit form
         to the native wxString representation.
@@ -1834,7 +1835,7 @@ public:
     static wxString FromAscii(const char* s, size_t len);
     static wxString FromAscii(const unsigned char* s, size_t len);
     static wxString FromAscii(char c);
-    //@}
+    ///@}
 
     /**
         Returns a string with the textual representation of the number in C
@@ -1874,7 +1875,7 @@ public:
      */
     static wxString FromDouble(double val, int precision = -1);
 
-    //@{
+    ///@{
     /**
         Converts C string encoded in UTF-8 to wxString.
 
@@ -1892,9 +1893,9 @@ public:
     static wxString FromUTF8(const char* s);
     static wxString FromUTF8(const char* s, size_t len);
     static wxString FromUTF8(const std::string& s);
-    //@}
+    ///@}
 
-    //@{
+    ///@{
     /**
         Converts C string encoded in UTF-8 to wxString without checking its
         validity.
@@ -1916,12 +1917,12 @@ public:
     static wxString FromUTF8Unchecked(const char* s);
     static wxString FromUTF8Unchecked(const char* s, size_t len);
     static wxString FromUTF8Unchecked(const std::string& s);
-    //@}
+    ///@}
 };
 
 
 
-//@{
+///@{
 /**
     Comparison operator for string types.
 */
@@ -1943,9 +1944,9 @@ inline bool operator==(const wxString& s1, const wxCharBuffer& s2);
 inline bool operator==(const wxCharBuffer& s1, const wxString& s2);
 inline bool operator!=(const wxString& s1, const wxCharBuffer& s2);
 inline bool operator!=(const wxCharBuffer& s1, const wxString& s2);
-//@}
+///@}
 
-//@{
+///@{
 /**
     Comparison operators char types.
 */
@@ -1967,7 +1968,7 @@ inline bool operator!=(const wxString& s, const wxUniChar& c);
 inline bool operator!=(const wxString& s, const wxUniCharRef& c);
 inline bool operator!=(const wxString& s, char c);
 inline bool operator!=(const wxString& s, wchar_t c);
-//@}
+///@}
 
 /**
     The global wxString instance of an empty string.
@@ -2099,7 +2100,7 @@ public:
 
 
 /** @addtogroup group_funcmacro_string */
-//@{
+///@{
 
 /**
     Allows extending a function with the signature:
@@ -2131,4 +2132,4 @@ template<bool (T)(const wxUniChar& c)>
  */
 wxString wxASCII_STR(const char* s);
 
-//@}
+///@}
