@@ -69,8 +69,10 @@ enum wxTextAttrAlignment
     wxTEXT_ALIGNMENT_CENTER = wxTEXT_ALIGNMENT_CENTRE,
     wxTEXT_ALIGNMENT_RIGHT,
 
-    /** wxTEXT_ALIGNMENT_JUSTIFIED is unimplemented.
-        In future justification may be supported when printing or previewing, only. */
+    /** wxTEXT_ALIGNMENT_JUSTIFIED is implemented for wxTextCtrl under wxMSW, wxOSX and wxGTK.
+        It is not implemented for wxRichTextCtrl.
+        In the future, wxRichTextCtrl justification may be supported when
+        printing or previewing only. */
     wxTEXT_ALIGNMENT_JUSTIFIED
 };
 
@@ -264,6 +266,9 @@ enum wxTextCtrlHitTestResult
     wxTextAttr represents the character and paragraph attributes, or style,
     for a range of text in a wxTextCtrl or wxRichTextCtrl.
 
+    Unless explicitly mentioned, the attributes are only implemented in wxRichTextCtrl,
+    and not wxTextCtrl.
+
     When setting up a wxTextAttr object, pass a bitlist mask to
     wxTextAttr::SetFlags() to indicate which style elements should be changed.
     As a convenience, when you call a setter such as SetFont, the relevant bit
@@ -328,11 +333,17 @@ public:
     /**
         Returns the alignment flags.
         See ::wxTextAttrAlignment for a list of available styles.
+
+        For wxTextCtrl, is implemented under wxMSW, wxOSX and wxGTK.
+        Also implemented in wxRichTextCtrl.
     */
     wxTextAttrAlignment GetAlignment() const;
 
     /**
         Returns the background colour.
+
+        For wxTextCtrl, is implemented under wxMSW, wxOSX and wxGTK.
+        Also implemented in wxRichTextCtrl.
     */
     const wxColour& GetBackgroundColour() const;
 
@@ -362,12 +373,18 @@ public:
 
     /**
         Returns the bullet number.
+
+        For wxTextCtrl, is implemented under wxMSW.
+        Also implemented in wxRichTextCtrl.
     */
     int GetBulletNumber() const;
 
     /**
         Returns the bullet style.
         See ::wxTextAttrBulletStyle for a list of available styles.
+
+        For wxTextCtrl, is implemented under wxMSW.
+        Also implemented in wxRichTextCtrl.
     */
     int GetBulletStyle() const;
 
@@ -394,6 +411,9 @@ public:
         a temporary font.
 
         For greater efficiency, access the font attributes directly.
+
+        For wxTextCtrl, is implemented under wxMSW, wxOSX and wxGTK.
+        Also implemented in wxRichTextCtrl.
     */
     wxFont GetFont() const;
 
@@ -437,6 +457,9 @@ public:
     /**
         Returns the underline type, which is one of the wxTextAttrUnderlineType values.
 
+        For wxTextCtrl, is implemented under wxMSW, wxOSX and wxGTK.
+        Also implemented in wxRichTextCtrl.
+
         @since 3.1.3
     */
     wxTextAttrUnderlineType GetUnderlineType() const;
@@ -444,6 +467,9 @@ public:
     /**
         Returns the underline color used. wxNullColour when the text colour is used.
 
+        For wxTextCtrl, is implemented under wxMSW, wxOSX and wxGTK.
+        Also implemented in wxRichTextCtrl.
+
         @since 3.1.3
     */
     const wxColour& GetUnderlineColour() const;
@@ -455,16 +481,25 @@ public:
 
     /**
         Returns the left indent in tenths of a millimetre.
+
+        For wxTextCtrl, is implemented under wxMSW and wxGTK.
+        Also implemented in wxRichTextCtrl.
     */
     long GetLeftIndent() const;
 
     /**
         Returns the left sub-indent in tenths of a millimetre.
+
+        For wxTextCtrl, is implemented under wxMSW and wxGTK.
+        Also implemented in wxRichTextCtrl.
     */
     long GetLeftSubIndent() const;
 
     /**
         Returns the line spacing value, one of ::wxTextAttrLineSpacing values.
+
+        For wxTextCtrl, is implemented under wxMSW.
+        Also implemented in wxRichTextCtrl.
     */
     int GetLineSpacing() const;
 
@@ -480,11 +515,17 @@ public:
 
     /**
         Returns the space in tenths of a millimeter after the paragraph.
+
+        For wxTextCtrl, is implemented under wxMSW.
+        Also implemented in wxRichTextCtrl.
     */
     int GetParagraphSpacingAfter() const;
 
     /**
         Returns the space in tenths of a millimeter before the paragraph.
+
+        For wxTextCtrl, is implemented under wxMSW.
+        Also implemented in wxRichTextCtrl.
     */
     int GetParagraphSpacingBefore() const;
 
@@ -495,6 +536,9 @@ public:
 
     /**
         Returns the right indent in tenths of a millimeter.
+
+        For wxTextCtrl, is implemented under wxMSW.
+        Also implemented in wxRichTextCtrl.
     */
     long GetRightIndent() const;
 
@@ -503,11 +547,17 @@ public:
 
         Each stop is measured from the left margin and therefore each value must
         be larger than the last.
+
+        For wxTextCtrl, is implemented under wxMSW and wxGTK.
+        Also implemented in wxRichTextCtrl.
     */
     const wxArrayInt& GetTabs() const;
 
     /**
         Returns the text foreground colour.
+
+        For wxTextCtrl, is implemented under wxMSW, wxOSX and wxGTK.
+        Also implemented in wxRichTextCtrl.
     */
     const wxColour& GetTextColour() const;
 
@@ -544,11 +594,17 @@ public:
 
     /**
         Returns @true if the attribute object specifies alignment.
+
+        For wxTextCtrl, is implemented under wxMSW, wxOSX and wxGTK.
+        Also implemented in wxRichTextCtrl.
     */
     bool HasAlignment() const;
 
     /**
         Returns @true if the attribute object specifies a background colour.
+
+        For wxTextCtrl, is implemented under wxMSW, wxOSX and wxGTK.
+        Also implemented in wxRichTextCtrl.
     */
     bool HasBackgroundColour() const;
 
@@ -559,11 +615,17 @@ public:
 
     /**
         Returns @true if the attribute object specifies a bullet number.
+
+        For wxTextCtrl, is implemented under wxMSW.
+        Also implemented in wxRichTextCtrl.
     */
     bool HasBulletNumber() const;
 
     /**
         Returns @true if the attribute object specifies a bullet style.
+
+        For wxTextCtrl, is implemented under wxMSW.
+        Also implemented in wxRichTextCtrl.
     */
     bool HasBulletStyle() const;
 
@@ -586,6 +648,9 @@ public:
 
     /**
         Returns @true if the attribute object specifies any font attributes.
+
+        For wxTextCtrl, is implemented under wxMSW, wxOSX and wxGTK.
+        Also implemented in wxRichTextCtrl.
     */
     bool HasFont() const;
 
@@ -638,11 +703,17 @@ public:
 
     /**
         Returns @true if the attribute object specifies a left indent.
+
+        For wxTextCtrl, is implemented under wxMSW and wxGTK.
+        Also implemented in wxRichTextCtrl.
     */
     bool HasLeftIndent() const;
 
     /**
         Returns @true if the attribute object specifies line spacing.
+
+        For wxTextCtrl, is implemented under wxMSW and wxOSX.
+        Also implemented in wxRichTextCtrl.
     */
     bool HasLineSpacing() const;
 
@@ -664,11 +735,17 @@ public:
 
     /**
         Returns @true if the attribute object specifies spacing after a paragraph.
+
+        For wxTextCtrl, is implemented under wxMSW.
+        Also implemented in wxRichTextCtrl.
     */
     bool HasParagraphSpacingAfter() const;
 
     /**
         Returns @true if the attribute object specifies spacing before a paragraph.
+
+        For wxTextCtrl, is implemented under wxMSW and wxGTK.
+        Also implemented in wxRichTextCtrl.
     */
     bool HasParagraphSpacingBefore() const;
 
@@ -684,11 +761,17 @@ public:
 
     /**
         Returns @true if the attribute object specifies tab stops.
+
+        For wxTextCtrl, is implemented under wxMSW and wxGTK.
+        Also implemented in wxRichTextCtrl.
     */
     bool HasTabs() const;
 
     /**
         Returns @true if the attribute object specifies a text foreground colour.
+
+        For wxTextCtrl, is implemented under wxMSW, wxOSX and wxGTK.
+        Also implemented in wxRichTextCtrl.
     */
     bool HasTextColour() const;
 
@@ -732,13 +815,19 @@ public:
     /**
         Sets the paragraph alignment. See ::wxTextAttrAlignment enumeration values.
 
-        Of these, wxTEXT_ALIGNMENT_JUSTIFIED is unimplemented.
-        In future justification may be supported when printing or previewing, only.
+        wxTEXT_ALIGNMENT_JUSTIFIED is not implemented for wxRichTextCtrl. In the future, wxRichTextCtrl
+        justification may be supported when printing or previewing only.
+
+        For wxTextCtrl, is implemented under wxMSW, wxOSX and wxGTK.
+        Also implemented in wxRichTextCtrl.
     */
     void SetAlignment(wxTextAttrAlignment alignment);
 
     /**
         Sets the background colour.
+
+        For wxTextCtrl, is implemented under wxMSW, wxOSX and wxGTK.
+        Also implemented in wxRichTextCtrl.
     */
     void SetBackgroundColour(const wxColour& colBack);
 
@@ -759,14 +848,25 @@ public:
 
     /**
         Sets the bullet number.
+
+        For wxTextCtrl, is implemented under wxMSW.
+        Also implemented in wxRichTextCtrl.
     */
     void SetBulletNumber(int n);
 
     /**
         Sets the bullet style.
 
-        The ::wxTextAttrBulletStyle enumeration values are all supported,
+        For wxTextCtrl, is implemented under wxMSW.
+        Also implemented in wxRichTextCtrl.
+
+        For wxRichTextCtrl, the ::wxTextAttrBulletStyle enumeration values are all supported,
         except for wxTEXT_ATTR_BULLET_STYLE_BITMAP.
+
+        For wxTextCtrl under wxMSW, the ::wxTextAttrBulletStyle enumeration values are all supported,
+        except for wxTEXT_ATTR_BULLET_STYLE_BITMAP, wxTEXT_ATTR_BULLET_STYLE_OUTLINE,
+        wxTEXT_ATTR_BULLET_STYLE_ALIGN_LEFT, wxTEXT_ATTR_BULLET_STYLE_ALIGN_RIGHT,
+        wxTEXT_ATTR_BULLET_STYLE_ALIGN_CENTRE, and wxTEXT_ATTR_BULLET_STYLE_CONTINUATION.
     */
     void SetBulletStyle(int style);
 
@@ -790,6 +890,9 @@ public:
     /**
         Sets the attributes for the given font.
         Note that wxTextAttr does not store an actual wxFont object.
+
+        For wxTextCtrl, is implemented under wxMSW, wxOSX and wxGTK.
+        Also implemented in wxRichTextCtrl.
     */
     void SetFont(const wxFont& font, int flags = wxTEXT_ATTR_FONT & ~wxTEXT_ATTR_FONT_PIXEL_SIZE);
 
@@ -877,6 +980,9 @@ public:
         at leftMargin + leftSubIndent.
         So the distance between the left edge of the bullet and the
         left of the actual paragraph is leftSubIndent.
+
+        For wxTextCtrl, is implemented under wxMSW and wxGTK.
+        Also implemented in wxRichTextCtrl.
     */
     void SetLeftIndent(int indent, int subIndent = 0);
 
@@ -884,6 +990,9 @@ public:
         Sets the line spacing. @a spacing is a multiple, where 10 means single-spacing,
         15 means 1.5 spacing, and 20 means double spacing.
         The ::wxTextAttrLineSpacing values are defined for convenience.
+
+        For wxTextCtrl, is implemented under wxMSW.
+        Also implemented in wxRichTextCtrl.
     */
     void SetLineSpacing(int spacing);
 
@@ -907,11 +1016,17 @@ public:
 
     /**
         Sets the spacing after a paragraph, in tenths of a millimetre.
+
+        For wxTextCtrl, is implemented under wxMSW.
+        Also implemented in wxRichTextCtrl.
     */
     void SetParagraphSpacingAfter(int spacing);
 
     /**
         Sets the spacing before a paragraph, in tenths of a millimetre.
+
+        For wxTextCtrl, is implemented under wxMSW.
+        Also implemented in wxRichTextCtrl.
     */
     void SetParagraphSpacingBefore(int spacing);
 
@@ -929,6 +1044,9 @@ public:
         Sets the tab stops, expressed in tenths of a millimetre.
         Each stop is measured from the left margin and therefore each value must be
         larger than the last.
+
+        For wxTextCtrl, is implemented under wxMSW and wxGTK.
+        Also implemented in wxRichTextCtrl.
     */
     void SetTabs(const wxArrayInt& tabs);
 
@@ -1767,7 +1885,7 @@ public:
     ///@{
 
     /**
-        Enable the automatic replacement of new lines characters in a
+        Enables the automatic replacement of new lines characters in a
         single-line text field with spaces under macOS.
 
         This feature is enabled by default and will replace any new line (`\n`)
@@ -1780,14 +1898,44 @@ public:
         the restriction preventing multiple lines from being entered unless
         wxTE_MULTILINE is specified.
 
-        @note This function is only available for macOS/Cocoa. It also has no
-        effect if the wxTE_MULTILINE flag is set on a text control.
+        @note Has no effect if the wxTE_MULTILINE flag is set on a text control.
 
         @onlyfor{wxosx}
         @since 3.1.6
     */
     void OSXEnableNewLineReplacement(bool enable);
 
+    /**
+        Enables the automatic replacement of ASCII quotation marks and
+        apostrophes with their typographic symbols.
+
+        This feature is enabled by default.
+
+        @onlyfor{wxosx}
+        @since 3.1.1
+    */
+    void OSXEnableAutomaticQuoteSubstitution(bool enable);
+
+    /**
+        Enables the automatic conversion of two ASCII hyphens into an m-dash.
+
+        This feature is enabled by default.
+
+        @onlyfor{wxosx}
+        @since 3.1.1
+    */
+    void OSXEnableAutomaticDashSubstitution(bool enable);
+
+    /**
+        Disables all automatic character substitutions.
+
+        @onlyfor{wxosx}
+        @since 3.1.1
+
+        @see OSXEnableAutomaticQuoteSubstitution(), OSXEnableAutomaticDashSubstitution()
+    */
+    void OSXDisableAllSmartSubstitutions();
+
     ///@}
 
     ///@{
