@@ -486,6 +486,8 @@ public:
     virtual WXHDC GetNativeHDC() wxOVERRIDE;
     virtual void ReleaseNativeHDC(WXHDC hdc) wxOVERRIDE;
 
+    class OffsetHelper;
+
 protected:
     // Used from ctors (including those in the derived classes) and takes
     // ownership of the graphics pointer that must be non-NULL.
@@ -1825,32 +1827,42 @@ void * wxGDIPlusMatrixData::GetNativeMatrix() const
 // wxGDIPlusContext implementation
 //-----------------------------------------------------------------------------
 
-class wxGDIPlusOffsetHelper
+class wxGDIPlusContext::OffsetHelper
 {
 public :
-    wxGDIPlusOffsetHelper(Graphics* gr, double scaleFactor, bool offset)
+    OffsetHelper(wxGDIPlusContext* gc, Graphics* gr, const wxGraphicsPen& pen)
     {
+        m_shouldOffset = gc->ShouldOffset();
+        if (!m_shouldOffset)
+            return;
+
         m_gr = gr;
-        m_offset = 0;
-        if (offset)
+        m_offsetX = m_offsetY = 0.5f;
+
+        const double width = static_cast<wxGDIPlusPenData*>(pen.GetRefData())->GetWidth();
+        if (width <= 0)
         {
+            // For 1-pixel pen width, offset by half a device pixel
             Matrix matrix;
             gr->GetTransform(&matrix);
-            const float f = float(scaleFactor);
+            const float f = float(gc->GetContentScaleFactor());
             PointF pt(f, f);
             matrix.TransformVectors(&pt);
-            m_offset = 0.5f / wxMin(std::abs(pt.X), std::abs(pt.Y));
-            m_gr->TranslateTransform(m_offset, m_offset);
+            m_offsetX /= pt.X;
+            m_offsetY /= pt.Y;
         }
+
+        gr->TranslateTransform(m_offsetX, m_offsetY);
     }
-    ~wxGDIPlusOffsetHelper( )
+    ~OffsetHelper()
     {
-        if (m_offset > 0)
-            m_gr->TranslateTransform(-m_offset, -m_offset);
+        if (m_shouldOffset)
+            m_gr->TranslateTransform(-m_offsetX, -m_offsetY);
     }
 public :
     Graphics* m_gr;
-    float m_offset;
+    float m_offsetX, m_offsetY;
+    bool m_shouldOffset;
 } ;
 
 wxGDIPlusContext::wxGDIPlusContext( wxGraphicsRenderer* renderer, HDC hdc, wxDouble width, wxDouble height   )
@@ -1987,7 +1999,7 @@ void wxGDIPlusContext::DrawRectangle( wxDouble x, wxDouble y, wxDouble w, wxDoub
     if (m_composition == wxCOMPOSITION_DEST)
         return;
 
-    wxGDIPlusOffsetHelper helper(m_context, GetContentScaleFactor(), ShouldOffset());
+    OffsetHelper helper(this, m_context, m_pen);
     Brush *brush = m_brush.IsNull() ? NULL : ((wxGDIPlusBrushData*)m_brush.GetRefData())->GetGDIPlusBrush();
     Pen *pen = m_pen.IsNull() ? NULL : ((wxGDIPlusPenData*)m_pen.GetGraphicsData())->GetGDIPlusPen();
 
@@ -2026,7 +2038,7 @@ void wxGDIPlusContext::StrokeLines( size_t n, const wxPoint2DDouble *points)
 
    if ( !m_pen.IsNull() )
    {
-        wxGDIPlusOffsetHelper helper(m_context, GetContentScaleFactor(), ShouldOffset());
+        OffsetHelper helper(this, m_context, m_pen);
        PointF *cpoints = new PointF[n];
        for (size_t i = 0; i < n; i++)
        {
@@ -2044,7 +2056,7 @@ void wxGDIPlusContext::DrawLines( size_t n, const wxPoint2DDouble *points, wxPol
    if (m_composition == wxCOMPOSITION_DEST)
         return;
 
-    wxGDIPlusOffsetHelper helper(m_context, GetContentScaleFactor(), ShouldOffset());
+    OffsetHelper helper(this, m_context, m_pen);
     PointF *cpoints = new PointF[n];
     for (size_t i = 0; i < n; i++)
     {
@@ -2067,7 +2079,7 @@ void wxGDIPlusContext::StrokePath( const wxGraphicsPath& path )
 
     if ( !m_pen.IsNull() )
     {
-        wxGDIPlusOffsetHelper helper(m_context, GetContentScaleFactor(), ShouldOffset());
+        OffsetHelper helper(this, m_context, m_pen);
         m_context->DrawPath( ((wxGDIPlusPenData*)m_pen.GetGraphicsData())->GetGDIPlusPen() , (GraphicsPath*) path.GetNativePath() );
     }
 }
@@ -2079,7 +2091,7 @@ void wxGDIPlusContext::FillPath( const wxGraphicsPath& path , wxPolygonFillMode
 
     if ( !m_brush.IsNull() )
     {
-        wxGDIPlusOffsetHelper helper(m_context, GetContentScaleFactor(), ShouldOffset());
+        OffsetHelper helper(this, m_context, m_pen);
         ((GraphicsPath*) path.GetNativePath())->SetFillMode( fillStyle == wxODDEVEN_RULE ? FillModeAlternate : FillModeWinding);
         m_context->FillPath( ((wxGDIPlusBrushData*)m_brush.GetRefData())->GetGDIPlusBrush() ,
             (GraphicsPath*) path.GetNativePath());
@@ -2473,15 +2485,9 @@ bool wxGDIPlusContext::ShouldOffset() const
     if (width <= 0)
         return true;
 
-    // no offset if overall scale is not odd integer
-    const wxGraphicsMatrix matrix(GetTransform());
-    double x = GetContentScaleFactor(), y = x;
-    matrix.TransformDistance(&x, &y);
-    if (!wxIsSameDouble(fmod(wxMin(fabs(x), fabs(y)), 2.0), 1.0))
-        return false;
-
     // offset if pen width is odd integer
-    return wxIsSameDouble(fmod(width, 2.0), 1.0);
+    const int w = int(width);
+    return (w & 1) && wxIsSameDouble(width, w);
 }
 
 void* wxGDIPlusContext::GetNativeContext()
