@@ -2059,6 +2059,15 @@ int wxPGProperty::GetChoiceSelection() const
 void wxPGProperty::SetChoiceSelection( int newValue )
 {
     wxCHECK_RET( m_choices.IsOk(), wxS("invalid choiceinfo") );
+
+    // Allow setting the value of -1 to reset the selection, for consistency
+    // with wxChoice::SetSelection().
+    if ( newValue == wxNOT_FOUND )
+    {
+        SetValueToUnspecified();
+        return;
+    }
+
     wxCHECK_RET( newValue >= 0 && newValue < (int)m_choices.GetCount(),
                  wxS("New index is out of range") );
 
