@@ -127,7 +127,7 @@ struct Date
     wxDateTime::wxDateTime_t hour, min, sec;
     double jdn;
     wxDateTime::WeekDay wday;
-    time_t gmticks;
+    wxInt64 gmticks;
 
     void Init(const wxDateTime::Tm& tm)
     {
@@ -184,7 +184,8 @@ static const Date testDates[] =
     {  8, wxDateTime::Feb,  2036, 00, 00, 00, 2464731.5, wxDateTime::Fri,        -1 },
     {  1, wxDateTime::Jan,  2037, 00, 00, 00, 2465059.5, wxDateTime::Thu,        -1 },
     {  1, wxDateTime::Jan,  2038, 00, 00, 00, 2465424.5, wxDateTime::Fri,        -1 },
-    { 21, wxDateTime::Jan,  2222, 00, 00, 00, 2532648.5, wxDateTime::Mon,        -1 },
+    {  1, wxDateTime::Jan,  2044, 00, 00, 00, 2467615.5, wxDateTime::Fri, 2335219200LL },
+    { 21, wxDateTime::Jan,  2222, 00, 00, 00, 2532648.5, wxDateTime::Mon, 7954070400LL },
     { 29, wxDateTime::May,  1976, 12, 00, 00, 2442928.0, wxDateTime::Sat, 202219200 },
     { 29, wxDateTime::Feb,  1976, 00, 00, 00, 2442837.5, wxDateTime::Sun, 194400000 },
     {  1, wxDateTime::Jan,  1900, 12, 00, 00, 2415021.0, wxDateTime::Mon,        -1 },
@@ -684,6 +685,7 @@ void DateTimeTestCase::TestTimeFormat()
        { CompareYear, "Date is %x, time is %X" }, // %x could use 2 digits
        { CompareTime, "Time is %H:%M:%S or %I:%M:%S %p" },
        { CompareNone, "The day of year: %j, the week of year: %W" },
+       { CompareDate, "ISO date using short form: %F" },
        { CompareDate, "ISO date without separators: %Y%m%d" },
        { CompareBoth, "RFC 2822 string: %Y-%m-%d %H:%M:%S.%l %z" },
 
@@ -875,6 +877,20 @@ void DateTimeTestCase::TestTimeFormat()
     CPPUNIT_ASSERT( dt.ParseFormat("23", "%e") );
     CPPUNIT_ASSERT_EQUAL( 23, dt.GetDay() );
 
+    SECTION("%-")
+    {
+        REQUIRE( dt.ParseFormat("17.5.2024", "%-d.%-m.%Y") );
+        CHECK( dt.GetDay() == 17 );
+        CHECK( dt.GetMonth() == wxDateTime::May );
+        CHECK( dt.GetYear() == 2024 );
+
+        REQUIRE( dt.ParseFormat("8.5.2024", "%-d.%-m.%Y") );
+        CHECK( dt.GetDay() == 8 );
+
+        REQUIRE( dt.ParseFormat("11.11.2024", "%-d.%-m.%Y") );
+        CHECK( dt.GetMonth() == wxDateTime::Nov );
+    }
+
     // test partially specified dates too
     wxDateTime dtDef(26, wxDateTime::Sep, 2008);
     CPPUNIT_ASSERT( dt.ParseFormat("17", "%d", dtDef) );
@@ -1071,7 +1087,7 @@ void DateTimeTestCase::TestTimeTicks()
 
         INFO("n=" << n);
 
-        time_t ticks = (dt.GetValue() / 1000).ToLong();
+        wxInt64 ticks = (dt.GetValue() / 1000).GetValue();
         CHECK( d.gmticks == ticks );
     }
 }
@@ -1110,6 +1126,12 @@ void DateTimeTestCase::TestParseRFC822()
             true
         },
 
+        {
+            "Tue, 12 Apr 2044 10:48:30 -0500",
+            { 12, wxDateTime::Apr, 2044, 15, 48, 30 },
+            true
+        },
+
         {
             "Sat, 18 Dec 1999 10:48:30 G", // military time zone
             { 18, wxDateTime::Dec, 1999, 17, 48, 30 },
@@ -1282,6 +1304,7 @@ void DateTimeTestCase::TestDateParse()
         { "31/03/06",    { 31, wxDateTime::Mar,    6 }, true, "" },
         { "31/03/2006",  { 31, wxDateTime::Mar, 2006 }, true, "" },
         { "Thu 20 Jun 2019", { 20, wxDateTime::Jun, 2019 }, true, "" },
+        { "Sun 20 Jun 2049", { 20, wxDateTime::Jun, 2049 }, true, "" },
         { "20 Jun 2019 Thu", { 20, wxDateTime::Jun, 2019 }, true, "" },
         { "Dec sixth 2017",  {  6, wxDateTime::Dec, 2017 }, true, "" },
 
@@ -1434,6 +1457,14 @@ void DateTimeTestCase::TestDateTimeParse()
             false
         },
 
+        {
+            "Sun 20 Jun 2049 07:40:00 PM",
+            { 20, wxDateTime::Jun, 2049, 19, 40,  0 },
+            true,
+            "",
+            false
+        },
+
         {
             "2010-01-04 14:30",
             {  4, wxDateTime::Jan, 2010, 14, 30,  0 },
@@ -1442,6 +1473,15 @@ void DateTimeTestCase::TestDateTimeParse()
             false
         },
 
+        {
+            // with 'T' separator
+            "2010-01-04T14:30",
+            {  4, wxDateTime::Jan, 2010, 14, 30,  0 },
+            true,
+            "",
+            false
+        },
+
         {
             // date after time
             "14:30:00 2020-01-04",
