@@ -381,7 +381,7 @@ TEST_CASE("wxFileName::Normalize", "[filename]")
             wxRegKey::HKLM,
             "SYSTEM\\CurrentControlSet\\Control\\FileSystem"
          ).QueryValue("NtfsDisable8dot3NameCreation", &shortNamesDisabled) &&
-            shortNamesDisabled != 1 )
+            shortNamesDisabled != 1 && !IsAutomaticTest() )
     {
         wxFileName fn("TESTDA~1.CON");
         CHECK( fn.Normalize(wxPATH_NORM_LONG, cwd) );
@@ -1040,6 +1040,12 @@ TEST_CASE("wxFileName::GetSizeSpecial", "[filename][linux][special-file]")
     INFO( "size of /proc/kcore=" << size );
     CHECK( size > 0 );
 
+    if ( !wxFile::Exists("/sys/power/state") )
+    {
+        WARN("/sys/power/state doesn't exist, skipping test");
+        return;
+    }
+
     // All files in /sys are one page in size, irrespectively of the size of
     // their actual contents.
     CHECK( wxFileName::GetSize("/sys/power/state") == sysconf(_SC_PAGESIZE) );
