@@ -397,7 +397,7 @@ TEST_CASE_METHOD(BoxSizerTestCase, "BoxSizer::IncompatibleFlags", "[sizer]")
     // Combining two vertical alignment flags doesn't make sense.
     ASSERT_SIZER_INCOMPATIBLE_FLAGS(wxALIGN_BOTTOM, wxALIGN_CENTRE_VERTICAL);
 
-    // Combining wxEXPAND with vertical alignment doesn't make sense neither.
+    // Combining wxEXPAND with vertical alignment doesn't make sense either.
     ASSERT_SIZER_INCOMPATIBLE_FLAGS(wxEXPAND, wxALIGN_CENTRE_VERTICAL);
     ASSERT_SIZER_INCOMPATIBLE_FLAGS(wxEXPAND, wxALIGN_BOTTOM);
 
@@ -447,3 +447,39 @@ TEST_CASE_METHOD(BoxSizerTestCase, "BoxSizer::Replace", "[sizer]")
     m_sizer->AddSpacer(1);
     m_sizer->Replace(0, new wxSizerItem(new wxWindow(m_win, wxID_ANY)));
 }
+
+TEST_CASE("Sizer::CombineFlags", "[sizer]")
+{
+    // This is a compile-time test which simply verifies that we can combine
+    // all the different flags without getting any warnings about doing it --
+    // as would have been the case when using C++20 or later if we didn't use
+    // wxALLOW_COMBINING_ENUMS() for all these enums in wx/defs.h.
+    //
+    // These constants belong to the following enums, respectively:
+    //
+    //         wxALIGN_CENTER         wxAlignment
+    //         wxBORDER_NONE          wxBorder
+    //         wxLEFT                 wxDirection
+    //         wxCENTER               wxGeometryCentre
+    //         wxFIXED_MINSIZE        wxSizerFlagBits
+    //         wxEXPAND               wxStretch
+    //
+    int n = (wxALIGN_CENTER | wxBORDER_NONE)
+          | (wxALIGN_CENTER | wxLEFT)
+          | (wxALIGN_CENTER | wxCENTER)
+          | (wxALIGN_CENTER | wxFIXED_MINSIZE)
+          | (wxALIGN_CENTER | wxEXPAND)
+          | (wxBORDER_NONE | wxLEFT)
+          | (wxBORDER_NONE | wxCENTER)
+          | (wxBORDER_NONE | wxFIXED_MINSIZE)
+          | (wxBORDER_NONE | wxEXPAND)
+          | (wxLEFT | wxCENTER)
+          | (wxLEFT | wxFIXED_MINSIZE)
+          | (wxLEFT | wxEXPAND)
+          | (wxCENTER | wxFIXED_MINSIZE)
+          | (wxCENTER | wxEXPAND)
+          | (wxFIXED_MINSIZE | wxEXPAND)
+          ;
+
+    wxUnusedVar(n);
+}
