@@ -354,7 +354,7 @@ class RibbonButtonBar(RibbonControl):
                 self._bitmap_size_large = bitmap.GetSize()
                 if not bitmap_small.IsOk():
                     w, h = self._bitmap_size_large
-                    self._bitmap_size_small = wx.Size(0.5*w, 0.5*h)
+                    self._bitmap_size_small = wx.Size(w//2, h//2)
 
             if bitmap_small.IsOk():
 
@@ -608,10 +608,10 @@ class RibbonButtonBar(RibbonControl):
         :see: :meth:`~RibbonButtonBar.ClearButtons`
         """
 
-        for button in self._buttons:
+        for i, button in enumerate(self._buttons):
             if button.id == button_id:
                 self._layouts_valid = False
-                self._buttons.pop(button)
+                self._buttons.pop(i)
                 self.Realize()
                 self.Refresh()
                 return True
@@ -867,8 +867,8 @@ class RibbonButtonBar(RibbonControl):
 
             layout_size = self._layouts[layout_i].overall_size
             if layout_size.x <= new_size.x and layout_size.y <= new_size.y:
-                self._layout_offset.x = (new_size.x - layout_size.x)/2
-                self._layout_offset.y = (new_size.y - layout_size.y)/2
+                self._layout_offset.x = (new_size.x - layout_size.x)//2
+                self._layout_offset.y = (new_size.y - layout_size.y)//2
                 self._current_layout = layout_i
                 break
 
@@ -990,7 +990,7 @@ class RibbonButtonBar(RibbonControl):
 
     def MakeLayouts(self):
 
-        if self._layouts_valid or self._art == None:
+        if self._layouts_valid or self._art is None:
             return
 
         # Clear existing layouts
@@ -1075,7 +1075,7 @@ class RibbonButtonBar(RibbonControl):
         if count >= first_btn or used_width >= available_width:
             return False, count
 
-        if last_button != None:
+        if last_button is not None:
             last_button = count
 
         layout = RibbonButtonBarLayout()
@@ -1093,7 +1093,7 @@ class RibbonButtonBar(RibbonControl):
             # If height isn't preserved (i.e. it is reduced), then the minimum
             # size for the button bar will decrease, preventing the original
             # layout from being used (in some cases).
-            # It may be a good idea to always preverse the height, but for now
+            # It may be a good idea to always preserve the height, but for now
             # it is only done when the first button is involved in a collapse.
             preserve_height = True
 
@@ -1158,17 +1158,17 @@ class RibbonButtonBar(RibbonControl):
 
                 break
 
-        if new_hovered == None and self.GetToolTip():
+        if new_hovered is None and self.GetToolTip():
             self.SetToolTip("")
 
-        if new_hovered != self._hovered_button or (self._hovered_button != None and \
+        if new_hovered != self._hovered_button or (self._hovered_button is not None and \
                                                    new_hovered_state != self._hovered_button.base.state):
 
-            if self._hovered_button != None:
+            if self._hovered_button is not None:
                 self._hovered_button.base.state &= ~RIBBON_BUTTONBAR_BUTTON_HOVER_MASK
 
             self._hovered_button = new_hovered
-            if self._hovered_button != None:
+            if self._hovered_button is not None:
                 self._hovered_button.base.state = new_hovered_state
                 self.SetToolTip(self._hovered_button.base.help_string)
 
@@ -1298,12 +1298,12 @@ class RibbonButtonBar(RibbonControl):
         """
 
         repaint = False
-        if self._hovered_button != None:
+        if self._hovered_button is not None:
             self._hovered_button.base.state &= ~RIBBON_BUTTONBAR_BUTTON_HOVER_MASK
             self._hovered_button = None
             repaint = True
 
-        if self._active_button != None and not self._lock_active_state:
+        if self._active_button is not None and not self._lock_active_state:
             self._active_button.base.state &= ~RIBBON_BUTTONBAR_BUTTON_ACTIVE_MASK
             repaint = True
 
